@@ -1,4 +1,4 @@
-/* $Id: Base.h,v 1.6 1999/01/14 03:42:07 glgay Exp $ */
+/* $Id: Base.h,v 1.8 1999/02/23 13:57:18 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
@@ -106,8 +106,11 @@ class WObjectClass : public CObject {
    void addDestructor();
    void removeDestructor();
 
-   void manage() const { XtManageChild(*this); }
-   void unmanage() const { XtUnmanageChild(*this); }
+   void manage() { XtManageChild(*this); }
+   void unmanage() { XtUnmanageChild(*this); }
+
+   bool managed() const { return XtIsManaged(*this); }
+   void managed(bool state) { state ? manage() : unmanage(); }
 
    /* Most functions that denote a parameter of char * use the cvt functions */
    /* Be careful when changing the cvt function! */
@@ -158,6 +161,11 @@ class WObjectClass : public CObject {
    Atom addWMProtocol(char *atom_name, Bool add_if_exists=False);
    void addProtocol(Atom property, Atom protocol_to_add);
 
+   /* Convenience routines */
+   Boolean processTraversal(XmTraversalDirection d = XmTRAVERSE_CURRENT)
+       { return XmProcessTraversal(widget(), d); }
+   Widget getFocusWidget() { return XmGetFocusWidget(widget()); }
+
    /* ToolTip functions.  All are static except add and remove */
    /* ToolTip Enable/Disable, Timeout, and Margin effect all tooltips */
 
