@@ -1,4 +1,4 @@
-/* $Id: Composite.h,v 1.1.1.1 1997/03/19 13:32:20 glgay Exp $ */
+/* $Id: Composite.h,v 1.2 1999/01/15 01:40:38 glgay Exp $ */
 /*
  Copyright (C) 1993, 1994 Jettero Heller
  Copyright (C) 1994, 1995 Peter Williams
@@ -34,8 +34,8 @@ class CompositeClass : public CoreClass {
    virtual _XtString className() { return (_XtString) "Composite"; }
  public:
    void insertPosition(XtOrderProc);
-   WidgetList children();
-   int numChildren();
+   WidgetList children() const;
+   int numChildren() const;
 };
 
 #endif
