@@ -1,4 +1,4 @@
-/* $Id: ImageCache.h,v 1.1.1.1 1997/03/19 13:32:20 glgay Exp $ */
+/* $Id: ImageCache.h,v 1.3 1999/01/14 01:15:18 glgay Exp $ */
 /*
  Copyright (C) 1996 Peter Williams
  
@@ -19,25 +19,11 @@
 
 #if !defined(_XARM_IMAGECACHE_H_)
 #define _XARM_IMAGECACHE_H_
-#include <Xarm/adt.h>
-
-class ImageCache
-{
-   private:
-      ArmBinaryTree *_image_cache;
-
-   public:
-      ImageCache();
-      ~ImageCache();
-      void add(char *key, Pixmap pmap);
-      Pixmap find(char *key);
-};
 
 extern void XarmRegisterConverters();
-extern Pixmap XarmGetPixmap(Widget w, char *fname);
-extern Pixmap XarmGetPixmapFromData(Widget w, char **pdata);
+extern Pixmap XarmGetPixmap(Widget w, const char *fname);
+extern Pixmap XarmGetPixmapFromData(Widget w, const char **pdata);
 
-extern ImageCache _global_image_cache;
 
 #endif
 
